@@ -9,20 +9,14 @@ from tabulate import tabulate
 from ._ansi_colors import *
 from .formatters import *
 from .models import *
+from ..create.cfd.catalogos import Impuesto
+from ..create.retencion.catalogos import TipoImpuesto
 
 logger = logging.getLogger(__name__)
 
-ISR = "001"
-IVA = "002"
-IEPS = "003"
-
 IVA16 = "002|Tasa|0.160000"
 IVA08 = "002|Tasa|0.080000"
 
-RET_ISR = "01"
-RET_IVA = "02"
-RET_IEPS = "03"
-
 
 def complement_invoices_data(invoices: Mapping[UUID, SatCFDI]):
     for c in invoices.values():
@@ -75,22 +69,25 @@ def filter_invoices_iter(
     for r in invoices:
         if _compare(r["Emisor"]["Rfc"], rfc_emisor) \
                 and _compare(r["Receptor"]["Rfc"], rfc_receptor) \
-                and _compare(r.estatus, estatus) \
+                and _compare(r.estatus(), estatus) \
                 and _compare(r["Fecha"], fecha) \
                 and _compare(r.get("MetodoPago"), payment_method) \
                 and _compare(r["TipoDeComprobante"], invoice_type) \
-                and _compare(r.saldo_pendiente, pending_balance):
+                and _compare(r.saldo_pendiente(), pending_balance):
             yield r
 
 
-def filter_payments_iter(invoices: Mapping[UUID, SatCFDI], rfc_emisor=None, rfc_receptor=None, fecha=None) -> Sequence[PaymentsDetails]:
-    for r in filter_invoices_iter(invoices.values(), rfc_emisor=rfc_emisor, rfc_receptor=rfc_receptor, estatus='1', fecha=None):
+def filter_payments_iter(invoices: Mapping[UUID, SatCFDI], rfc_emisor=None, rfc_receptor=None, fecha=None, invoice_type=None) -> Sequence[PaymentsDetails]:
+    for r in filter_invoices_iter(invoices.values(), rfc_emisor=rfc_emisor, rfc_receptor=rfc_receptor, estatus='1', fecha=None, invoice_type=invoice_type):
         match r['TipoDeComprobante']:
             case "I":
-                if r['MetodoPago'] == PUE:
+                if r['MetodoPago'] == MetodoPago.PAGO_EN_UNA_SOLA_EXHIBICION:
                     if not r.payments:
                         if _compare(r["Fecha"], fecha):
-                            yield PaymentsDetails(comprobante=r)
+                            yield PaymentsDetails(
+                                comprobante=r,
+                                comprobante_pagado=r
+                            )
             case "P":
                 for p in r["Complemento"]["Pagos"]["Pago"]:
                     if _compare(p['FechaPago'], fecha):
@@ -101,6 +98,15 @@ def filter_payments_iter(invoices: Mapping[UUID, SatCFDI], rfc_emisor=None, rfc_
                                 docto_relacionado=dr,
                                 comprobante_pagado=invoices[UUID(dr["IdDocumento"])]
                             )
+            case "E":
+                if _compare(r["Fecha"], fecha):
+                    rel = list(cfdi_rel for cfdi_rel in r.cfdi_relacionados(TipoRelacion.NOTA_DE_CREDITO_DE_LOS_DOCUMENTOS_RELACIONADOS))
+                    assert len(rel) <= 1
+                    if len(rel) == 1:
+                        cp = invoices[rel[0]]
+                        yield PaymentsDetails(comprobante=r, comprobante_pagado=cp)
+                    else:
+                        yield PaymentsDetails(comprobante=r, comprobante_pagado=r)
 
 
 def filter_retenciones_iter(invoices, ejerc: int):
@@ -125,10 +131,10 @@ def invoice_def():
         'SubTotal': (12, True, lambda i: i["SubTotal"]),
         'Descuento': (12, True, lambda i: i.get("Descuento")),
         'IVA16 Tras': (12, True, lambda i: i.get("Impuestos", {}).get("Traslados", {}).get(IVA16, {}).get("Importe")),
-        'IVA Ret': (12, True, lambda i: i.get("Impuestos", {}).get("Retenciones", {}).get(IVA, {}).get("Importe")),
-        'ISR Ret': (12, True, lambda i: i.get("Impuestos", {}).get("Retenciones", {}).get(ISR, {}).get("Importe")),
+        'IVA Ret': (12, True, lambda i: i.get("Impuestos", {}).get("Retenciones", {}).get(Impuesto.IVA, {}).get("Importe")),
+        'ISR Ret': (12, True, lambda i: i.get("Impuestos", {}).get("Retenciones", {}).get(Impuesto.ISR, {}).get("Importe")),
         'Total': (12, True, lambda i: i["Total"]),
-        'Pendiente': (12, True, lambda i: i.saldo_pendiente or None),
+        'Pendiente': (12, True, lambda i: i.saldo_pendiente() or None),
         'Pagos': (35, False, format_pagos),
         'Relaciones': (35, False, format_relaciones),
         'Estado CFDI': (35, False, format_estado_cfdi),
@@ -148,8 +154,8 @@ def invoice_confirm_def():
         'SubTotal': (12, True, lambda i: i["SubTotal"]),
         'Descuento': (12, True, lambda i: i.get("Descuento")),
         'IVA16 Tras': (12, True, lambda i: i.get("Impuestos", {}).get("Traslados", {}).get(IVA16, {}).get("Importe")),
-        'IVA Ret': (12, True, lambda i: i.get("Impuestos", {}).get("Retenciones", {}).get(IVA, {}).get("Importe")),
-        'ISR Ret': (12, True, lambda i: i.get("Impuestos", {}).get("Retenciones", {}).get(ISR, {}).get("Importe")),
+        'IVA Ret': (12, True, lambda i: i.get("Impuestos", {}).get("Retenciones", {}).get(Impuesto.IVA, {}).get("Importe")),
+        'ISR Ret': (12, True, lambda i: i.get("Impuestos", {}).get("Retenciones", {}).get(Impuesto.ISR, {}).get("Importe")),
         'Total': (12, True, lambda i: i["Total"]),
         'Conceptos': (60, False, format_conceptos),
     }
@@ -168,15 +174,15 @@ def payment_def():
         'Factura Pagada': (12, False, lambda i: format_head(i.comprobante_pagado) if i.pago else "misma"),
         'Fecha de Pago': (12, False, lambda i: format_fecha_pago(i)),
 
-        'Pagado': (12, False, lambda i: i.total),
+        'Pagado': (12, True, lambda i: i.total),
         'Saldo Ant': (12, False, lambda i: i.docto_relacionado["ImpSaldoAnt"] if i.pago else i.comprobante["Total"]),
         'Saldo Insoluto': (12, False, lambda i: i.docto_relacionado["ImpSaldoInsoluto"] if i.pago else 0),
         'Parcialidad': (12, False, lambda i: i.docto_relacionado["NumParcialidad"] if i.pago else None),
         'Subtotal': (12, True, lambda i: i.sub_total),
         'Descuento': (12, True, lambda i: i.descuento),
         'IVA16 Tras': (12, True, lambda i: i.impuestos.get("Traslados", {}).get(IVA16, {}).get("Importe")),
-        'IVA Ret': (12, True, lambda i: i.impuestos.get("Retenciones", {}).get(IVA, {}).get("Importe")),
-        'ISR Ret': (12, True, lambda i: i.impuestos.get("Retenciones", {}).get(ISR, {}).get("Importe")),
+        'IVA Ret': (12, True, lambda i: i.impuestos.get("Retenciones", {}).get(Impuesto.IVA, {}).get("Importe")),
+        'ISR Ret': (12, True, lambda i: i.impuestos.get("Retenciones", {}).get(Impuesto.ISR, {}).get("Importe")),
 
         'Estatus SAT': (35, False, lambda i: format_estado_cfdi(i.comprobante)),
     }
@@ -188,7 +194,8 @@ def retenciones_def():
         'Monto de los intereses nominales': (12, False, lambda i: i["Complemento"]["Intereses"]["MontIntNominal"]),
         'Monto de los intereses reales': (12, False, lambda i: i["Complemento"]["Intereses"]["MontIntReal"]),
         'Perdida': (12, False, lambda i: i["Complemento"]["Intereses"]["Perdida"]),
-        'ISR Retenido': (12, False, lambda i: sum(x["MontoRet"] for x in i["Totales"]['ImpRetenidos'] if x.get("Impuesto") == RET_ISR) if 'ImpRetenidos' in i["Totales"] else None)
+        'ISR Retenido': (
+        12, False, lambda i: sum(x["MontoRet"] for x in i["Totales"]['ImpRetenidos'] if x.get("Impuesto") == TipoImpuesto.ISR) if 'ImpRetenidos' in i["Totales"] else None)
     }
 
 
@@ -241,7 +248,7 @@ def num2col(n):
     return name
 
 
-def excel_export(workbook: xlsxwriter.workbook.Workbook, name, invoices, columns):
+def excel_export(workbook: xlsxwriter.workbook.Workbook, name, invoices, columns, row_height=3):
     worksheet = workbook.add_worksheet(name)
 
     for n, (w, s, f) in enumerate(columns.values()):
@@ -268,7 +275,7 @@ def excel_export(workbook: xlsxwriter.workbook.Workbook, name, invoices, columns
     number_format = workbook.add_format({'num_format': '0.00'})
     number_format.set_align('top')
 
-    row_height = 20 * 3
+    row_height = 20 * row_height
     r = 0
     for r, i in enumerate(invoices):
         worksheet.set_row_pixels(1 + r, row_height)
@@ -313,7 +320,7 @@ def payments_groupby_receptor(payments: Sequence[PaymentsDetails]):
             "Receptor": receptor,
             "SubTotal": sum(p.sub_total for p in p),
             "Descuento": sum(p.descuento or 0 for p in p),
-            "ISR Ret": sum(p.impuestos.get("Retenciones", {}).get(ISR, {}).get("Importe") or 0 for p in p)
+            "ISR Ret": sum(p.impuestos.get("Retenciones", {}).get(Impuesto.ISR, {}).get("Importe") or 0 for p in p)
         })
     return res
 
