@@ -10,7 +10,8 @@ from cryptography.hazmat.primitives.asymmetric import padding, rsa
 from cryptography.hazmat.primitives.asymmetric.rsa import RSAPrivateKey
 from cryptography.hazmat.primitives.serialization import pkcs7
 
-from .. import Signer, Certificate, RFC, RFCType
+from .pkcs7 import create_pkcs7
+from ..models import Signer, Certificate, RFC, RFCType
 from ..ans1e import *
 from ..models.certificate import CertificateType
 from ..zip import zip_create, ZipData
@@ -103,13 +104,11 @@ class Certifica:
         return private_key
 
     def _pkcs7_package(self, data):
-        cert = self.signer.certificate.to_cryptography()
-        key = self.signer.key
-        options = [pkcs7.PKCS7Options.NoCapabilities, pkcs7.PKCS7Options.Binary]
-
-        return pkcs7.PKCS7SignatureBuilder().set_data(data) \
-            .add_signer(cert, key, hashes.SHA1()) \
-            .sign(serialization.Encoding.DER, options)
+        return create_pkcs7(
+            data=data,
+            signer=self.signer,
+            hash_algorithm=hashes.SHA1(),
+        )
 
 
 def _create_certificate_signing_request_zip(signer: Signer, private_key: RSAPrivateKey, sucursal: str):
@@ -157,10 +156,6 @@ def _create_renovation_moral_certificate_signing_request(signer: Signer, private
         k: v for k, v in cer.get_subject().get_components()
     }
 
-    print(signer.rfc)
-    print(subject_at[b'x500UniqueIdentifier'])
-    print(subject_at[b'serialNumber'])
-
     subject = {
         '2.5.4.45': (rfc.encode(ENCODING) + b' / ' + subject_at[b'x500UniqueIdentifier'], Numbers.PrintableString),
         '2.5.4.5': (b' / ' + subject_at[b'serialNumber'], Numbers.PrintableString),
