@@ -1,18 +1,18 @@
 import logging
 import os
 import lxml.etree
-from weasyprint import CSS
+from satcfdi.models import Signer
 
-from . import CFDIError, XElement
+from .exceptions import CFDIError
 from .transform import *
 from .transform.helpers import fmt_decimal
+from .xelement import XElement
 
 current_dir = os.path.dirname(__file__)
 logger = logging.getLogger(__name__)
 
 VERIFICA_CFDI = "https://verificacfdi.facturaelectronica.sat.gob.mx/default.aspx"
 VERIFICA_RETENCION = "https://prodretencionverificacion.clouda.sat.gob.mx/"
-PDF_CSS = CSS(string="@page {margin: 1.0cm 1.27cm 1.1cm 0.85cm;}")
 
 
 class CFDI(XElement):
@@ -83,3 +83,10 @@ class CFDI(XElement):
         transform = xslt_transform(self.tag, self['Version'])
         xml = super().to_xml()
         return str(transform(xml))
+
+    def sign(self, signer: Signer):
+        self['NoCertificado'] = signer.certificate_number
+        self['Certificado'] = signer.certificate_base64()
+        self['Sello'] = signer.sign_sha256(
+            self.cadena_original().encode()
+        )
