@@ -4,57 +4,15 @@ from dataclasses import dataclass
 from datetime import datetime
 from decimal import Decimal
 
-from .. import Signer
+from satcfdi.create.cfd.catalogos import Impuesto as CatImpuesto
 from . import pago20
 from ..compute import make_impuestos, rounder, make_impuesto, \
     make_impuestos_dr_parcial
-from ... import CFDI, ScalarMap
+from ...cfdi import CFDI
 from ...transform import get_timezone
+from ...utils import ScalarMap
 from ...utils import iterate
 
-_impuestos = {
-    "ISR": "001",
-    "IVA": "002",
-    "IEPS": "003",
-}
-
-
-class Impuesto(ScalarMap):
-    """
-    Nodo requerido para la información detallada de un impuesto específico.
-
-    :param base: Atributo requerido para señalar la suma de los atributos Base de los conceptos del impuesto trasladado. No se permiten valores negativos.
-    :param impuesto: Atributo requerido para señalar la clave del tipo de impuesto trasladado.
-    :param tipo_factor: Atributo requerido para señalar la clave del tipo de factor que se aplica a la base del impuesto.
-    :param tasa_o_cuota: Atributo condicional para señalar el valor de la tasa o cuota del impuesto que se traslada por los conceptos amparados en el comprobante.
-    :param importe: Atributo condicional para señalar la suma del importe del impuesto trasladado, agrupado por impuesto, TipoFactor y TasaOCuota. No se permiten valores negativos.
-    """
-
-    def __init__(
-            self,
-            impuesto: str,
-            tipo_factor: str,
-            tasa_o_cuota: Decimal | int = None,
-            importe: Decimal | int = None,
-            base: Decimal | int = None,
-    ):
-        super().__init__({
-            'Base': base,
-            'Impuesto': _impuestos.get(impuesto, impuesto),
-            'TipoFactor': tipo_factor,
-            'TasaOCuota': tasa_o_cuota,
-            'Importe': importe,
-        })
-
-    @classmethod
-    def parse(cls, impuesto: str) -> 'Impuesto':
-        parts = impuesto.split("|")
-        return cls(
-            impuesto=parts[0],
-            tipo_factor=parts[1],
-            tasa_o_cuota=Decimal(parts[2]) if len(parts) > 2 else None
-        )
-
 
 class CfdiRelacionados(ScalarMap):
     """
@@ -172,27 +130,36 @@ class Traslado(ScalarMap):
 
     def __init__(
             self,
-            base: Decimal | int,
             impuesto: str,
             tipo_factor: str,
             tasa_o_cuota: Decimal | int = None,
             importe: Decimal | int = None,
+            base: Decimal | int = None,
     ):
         super().__init__({
             'Base': base,
-            'Impuesto': impuesto,
+            'Impuesto': CatImpuesto.get(impuesto, impuesto),
             'TipoFactor': tipo_factor,
             'TasaOCuota': tasa_o_cuota,
             'Importe': importe,
         })
 
+    @classmethod  # obsolete
+    def parse(cls, impuesto: str):
+        parts = impuesto.split("|")
+        return cls(
+            impuesto=parts[0],
+            tipo_factor=parts[1],
+            tasa_o_cuota=Decimal(parts[2]) if len(parts) > 2 else None,
+        )
+
 
 class Retencion(ScalarMap):
     """
     Nodo requerido para la información detallada de un traslado de impuesto específico.
 
     :param base: Atributo requerido para señalar la suma de los atributos Base de los conceptos del impuesto trasladado. No se permiten valores negativos.
-    :param impuesto: Atributo requerido para señalar la clave del tipo de impuesto trasladado.
+    :param impuesto: Atributo requerido para señalar la clave del tipo de impuesto retencion.
     :param tipo_factor: Atributo requerido para señalar la clave del tipo de factor que se aplica a la base del impuesto.
     :param tasa_o_cuota: Atributo condicional para señalar el valor de la tasa o cuota del impuesto que se traslada por los conceptos amparados en el comprobante.
     :param importe: Atributo condicional para señalar la suma del importe del impuesto trasladado, agrupado por impuesto, TipoFactor y TasaOCuota. No se permiten valores negativos.
@@ -200,20 +167,29 @@ class Retencion(ScalarMap):
 
     def __init__(
             self,
-            base: Decimal | int,
             impuesto: str,
             tipo_factor: str,
             tasa_o_cuota: Decimal | int = None,
             importe: Decimal | int = None,
+            base: Decimal | int = None,
     ):
         super().__init__({
             'Base': base,
-            'Impuesto': impuesto,
+            'Impuesto': CatImpuesto.get(impuesto, impuesto),
             'TipoFactor': tipo_factor,
             'TasaOCuota': tasa_o_cuota,
             'Importe': importe,
         })
 
+    @classmethod  # obsolete
+    def parse(cls, impuesto: str):
+        parts = impuesto.split("|")
+        return cls(
+            impuesto=parts[0],
+            tipo_factor=parts[1],
+            tasa_o_cuota=Decimal(parts[2]) if len(parts) > 2 else None,
+        )
+
 
 class Impuestos(ScalarMap):
     """
@@ -351,7 +327,7 @@ class Emisor(ScalarMap):
             'RegimenFiscal': regimen_fiscal,
             'FacAtrAdquirente': fac_atr_adquirente,
         })
-        
+
 
 @dataclass
 class PagoComprobante:
@@ -373,8 +349,8 @@ class PagoComprobante:
 def _make_conceptos(conceptos, rnd_fn):
     def make_concepto(concepto):
         impuestos = concepto.get("Impuestos") or {}
-        trasladados = [x if isinstance(x, dict) else Impuesto.parse(x) for x in iterate(impuestos.get("Traslados"))]
-        retenciones = [x if isinstance(x, dict) else Impuesto.parse(x) for x in iterate(impuestos.get("Retenciones"))]
+        trasladados = [x if isinstance(x, dict) else Traslado.parse(x) for x in iterate(impuestos.get("Traslados"))]
+        retenciones = [x if isinstance(x, dict) else Retencion.parse(x) for x in iterate(impuestos.get("Retenciones"))]
 
         if concepto.get('_traslados_incluidos'):
             s_tasa = sum(c["TasaOCuota"] for c in trasladados if c["TipoFactor"] == "Tasa")
@@ -513,13 +489,6 @@ class Comprobante(CFDI):
         self['Total'] = total
         self['Descuento'] = descuento or None
 
-    def sign(self, signer: Signer):
-        self['NoCertificado'] = signer.certificate_number
-        self['Certificado'] = signer.certificate_base64()
-        self['Sello'] = signer.sign_sha256(
-            self.cadena_original().encode()
-        )
-
     @classmethod
     def pago(
             cls,
