@@ -2,7 +2,9 @@
 from decimal import Decimal
 from datetime import datetime, date, time
 from collections.abc import Sequence
-from ... import CFDI, XElement, ScalarMap
+from ...cfdi import CFDI
+from ...xelement import XElement
+from ...utils import ScalarMap
 
 
 class MovimientoECBFiscal(ScalarMap):
