@@ -1,7 +1,5 @@
-from decimal import Decimal
-from datetime import datetime, date, time
-from collections.abc import Sequence
-from ... import CFDI, XElement, ScalarMap
+from ...utils import ScalarMap
+from ...xelement import XElement
 
 
 class RSAKeyValueType(ScalarMap):
