@@ -3,14 +3,13 @@ from datetime import date, datetime
 from decimal import Decimal
 from io import BytesIO
 from typing import Sequence
-from zipfile import ZipFile, ZipInfo
 
 from .catalog import *
 from .code import *
 from .utils import _format_rfc, DIOTWriter, encrypt_triple_des, period_code, catalog_code
-from .. import RFC, RFCType, CURP, iterate, Certificate
 from ..ans1e import *
-from ..printer import Representable
+from ..models import RFC, RFCType, CURP, Certificate
+from ..utils import iterate
 
 __all__ = [
     'DIOT',
@@ -211,6 +210,34 @@ class ProveedorTercero:
         if self.devoluciones is not None:
             w(302261, 1, 1, self.devoluciones)
 
+    def to_list(self):
+        return [
+            self.tipo_tercero,
+            self.tipo_operacion,
+            self.rfc,
+            self.id_fiscal,
+            self.nombre_extranjero,
+            self.pais,
+            self.nacionalidad,
+            self.iva16,
+            "",
+            self.iva16_na,
+            "",
+            "",
+            self.iva_rfn,
+            "",
+            self.iva_rfn_na,
+            self.iva_import16,
+            self.iva_import16_na,
+            "",
+            "",
+            self.iva_import_exento,
+            self.iva0,
+            self.iva_exento,
+            self.retenido,
+            self.devoluciones
+        ]
+
 
 class DatosComplementaria:
     def __init__(
@@ -331,7 +358,7 @@ class DatosGenerales:
         }
 
 
-class DIOT(Representable):
+class DIOT:
     tag = "DIOT"
 
     def __init__(
@@ -339,9 +366,9 @@ class DIOT(Representable):
             datos_identificacion: DatosIdentificacion,
             periodo: Periodo,
             complementaria: DatosComplementaria = None,
-            proveedores: ProveedorTercero | Sequence[ProveedorTercero] = None
+            proveedores: Sequence[ProveedorTercero] = None
     ):
-        proveedores = iterate(proveedores)
+        proveedores = list(iterate(proveedores))
 
         self.datos_identificacion = datos_identificacion
         self.datos_generales = DatosGenerales(
@@ -375,7 +402,7 @@ class DIOT(Representable):
 
         w.end()
 
-    def _tmp_filename(self):
+    def filename(self):
         rfc = self.datos_identificacion.rfc
 
         if len(rfc) == 12:
@@ -399,6 +426,11 @@ class DIOT(Representable):
 
         return f"{rfc}{v_dem}{n_formulario}{ver_clte}{ver_form}{period}{mes_inicial}{period}{mes_final}{anio}{mes}{dia}{hora}{suffix}"
 
+    def export(self, target):
+        for p in self.proveedores:
+            target.write("|".join(str(v or "") for v in p.to_list()).encode('windows-1252'))
+            target.write(b"|\r\n")
+
     def plain_bytes(self) -> bytes:
         with BytesIO() as b:
             self.plain_write(b)
@@ -455,15 +487,15 @@ class DIOT(Representable):
                         e(data_encrypted.getvalue(), nr=0, cls=Classes.Context)
         e.stream(target)
 
-    def generate_package(self, dirname: str = None) -> str:
+    def generate_package(self, dirname: str = None, filename: str = None) -> str:
         """
         Generate Package, return filename
         """
-        tmp_filename = self._tmp_filename()
+        filename = filename or self.filename()
         if dirname:
-            filename = os.path.join(dirname, tmp_filename + ".dec")
+            out_file = os.path.join(dirname, filename + ".dec")
         else:
-            filename = tmp_filename + ".dec"
-        with open(filename, 'wb') as f:
-            self._encrypted_write(f, tmp_filename)
-        return filename
+            out_file = filename + ".dec"
+        with open(out_file, 'wb') as f:
+            self._encrypted_write(f, filename)
+        return out_file
