@@ -1,5 +1,4 @@
 import logging
-from enum import Enum
 
 logger = logging.getLogger(__name__)
 
@@ -31,6 +30,31 @@ class Code:
             return self.code == other.code
         return self.code == other
 
+    def __ne__(self, other):
+        if isinstance(other, Code):
+            return self.code != other.code
+        return self.code != other
+
+    def __lt__(self, other):
+        if isinstance(other, Code):
+            return self.code < other.code
+        return self.code < other
+
+    def __le__(self, other):
+        if isinstance(other, Code):
+            return self.code <= other.code
+        return self.code <= other
+
+    def __gt__(self, other):
+        if isinstance(other, Code):
+            return self.code > other.code
+        return self.code > other
+
+    def __ge__(self, other):
+        if isinstance(other, Code):
+            return self.code >= other.code
+        return self.code >= other
+
     def __hash__(self):
         return self.code.__hash__()
 
