@@ -17,10 +17,16 @@ from packaging import version
 import requests
 from lxml import etree
 from lxml.etree import QName
-from .. import Code
+from satcfdi.create.cfd.catalogos import TipoDeComprobante
 
-from .. import CFDI, __version__, ResponseError, Signer, Certificate
+from ..models import Code
+
+from .. import __version__
+from ..cfdi import CFDI
+from ..exceptions import ResponseError
+from ..models import Signer, Certificate
 from . import PAC, Environment, TaxpayerStatus
+from ..create.catalogos import EstadoComprobante
 from ..create.w3.signature import signature_c14n_sha1, _digest, _tobytes
 from ..transform import MEXICO_TZ, get_timezone, verify_certificate
 from ..utils import iterate, StrEnum, parser
@@ -33,30 +39,54 @@ REFRESH_TIME = (15 * 86400)  # 15 Days
 
 
 class EstadoSolicitud(IntEnum):
-    Aceptada = 1
-    EnProceso = 2
-    Terminada = 3
-    Error = 4
-    Rechazada = 5
-    Vencida = 6
+    ACEPTADA = 1
+    EN_PROCESO = 2
+    TERMINADA = 3
+    ERROR = 4
+    RECHAZADA = 5
+    VENCIDA = 6
+
+
+class CodigoEstadoSolicitud(StrEnum):
+    # 5000 Solicitud recibida con éxito
+    # Indica que la solicitud de descarga que se está
+    # verificando fue aceptada.
+    EXITO = "5000"
+
+    # 5002 Se agotó las solicitudes
+    # de por vida
+    # Para el caso de descarga de tipo CFDI, se tiene un
+    # límite máximo para solicitudes con los mismos
+    # parámetros (Fecha Inicial, Fecha Final, RfcEmisor,
+    # RfcReceptor).
+    AGOTADO = "5002"
+
+    # 5003 Tope máximo Indica que en base a los parámetros de consulta
+    # se está superando el tope máximo de CFDI o
+    # Metadata, por solicitud de descarga masiva.
+    TOPE_MAXIMO = "5003"
+
+    # 5004 No se encontró la información
+    # Indica que la solicitud de descarga que se está
+    # verificando no generó paquetes por falta de
+    # información.
+    NO_ENCONTRADO = "5004"
+
+    # 5005 Solicitud duplicada En caso de que exista una solicitud vigente con
+    # los mismos parámetros (Fecha Inicial, Fecha Final,
+    # RfcEmisor, RfcReceptor, TipoSolicitud), no se
+    # permitirá generar una nueva solicitud.
+    DUPLICADO = "5005"
+
+    # 404 Error no Controlado Error genérico, en caso de presentarse realizar
+    # nuevamente la petición y si persiste el error
+    # levantar un RMA.
+    ERROR_NO_CONTROLADO = "404"
 
 
 class TipoDescargaMasivaTerceros(StrEnum):
     CFDI = 'CFDI'
-    Metadata = 'Metadata'
-
-
-class TipoDeComprobante(StrEnum):
-    Ingreso = 'I'
-    Egreso = 'E'
-    Traslado = 'T'
-    Nomina = 'N'
-    Pago = 'P'
-
-
-class EstadoComprobante(StrEnum):
-    Cancelado = '0'
-    Vigente = '1'
+    METADATA = 'Metadata'
 
 
 def _service_logger(response_type, response):
@@ -243,8 +273,7 @@ class _CFDIVerificaSolicitudDescarga(_SATRequest):
             at = node.attrib.get('CodEstatus')
             if at is not None:
                 result['CodEstatus'] = at
-            estado_solicitud = int(node.attrib['EstadoSolicitud'])
-            result['EstadoSolicitud'] = Code(estado_solicitud, EstadoSolicitud(estado_solicitud).name)
+            result['EstadoSolicitud'] = int(node.attrib['EstadoSolicitud'])
             at = node.attrib.get('CodigoEstadoSolicitud')
             if at is not None:
                 result['CodigoEstadoSolicitud'] = at
@@ -654,7 +683,7 @@ class SAT(PAC):
             )
             _service_logger("VerificaSolicitudDescargaResult", response)
             est = response["EstadoSolicitud"]
-            if est == EstadoSolicitud.Terminada:
+            if est == EstadoSolicitud.TERMINADA:
                 for id_paquete in response['IdsPaquetes']:
                     response, paquete = self.recover_comprobante_download(
                         id_paquete=id_paquete
@@ -662,7 +691,7 @@ class SAT(PAC):
                     _service_logger("RespuestaDescargaMasivaTercerosSalida", response)
                     yield id_paquete, base64.b64decode(paquete)
                 break
-            if est in [EstadoSolicitud.Aceptada, EstadoSolicitud.EnProceso]:
+            if est in [EstadoSolicitud.ACEPTADA, EstadoSolicitud.EN_PROCESO]:
                 time.sleep(self.wait_time)
                 continue
             break
@@ -802,7 +831,7 @@ class SAT(PAC):
             )
             _service_logger("VerificaSolicitudDescargaResult", response)
             est = response["EstadoSolicitud"]
-            if est == EstadoSolicitud.Terminada:
+            if est == EstadoSolicitud.TERMINADA:
                 for id_paquete in response['IdsPaquetes']:
                     response, paquete = self.recover_retencion_download(
                         id_paquete=id_paquete
@@ -810,7 +839,7 @@ class SAT(PAC):
                     _service_logger("RespuestaDescargaMasivaTercerosSalida", response)
                     yield id_paquete, base64.b64decode(paquete)
                 break
-            if est in [EstadoSolicitud.Aceptada, EstadoSolicitud.EnProceso]:
+            if est in [EstadoSolicitud.ACEPTADA, EstadoSolicitud.EN_PROCESO]:
                 time.sleep(self.wait_time)
                 continue
             break
