@@ -4,53 +4,38 @@ from functools import cache
 import pytz
 from lxml import etree
 
-# noinspection PyUnresolvedReferences
-from .catalog import TRANSLATIONS, CATALOGS
 from .helpers import SchemaCollector
 from .objectify import cfdi_objectify
-from .pdf_environment import DefaultPDFEnvironment
 from .schemas import cfdi_schemas
 from .xmlify import cfdi_xmlify
 from .xslt import TRANSFORMS
-from .. import SchemaValidationError, CFDIError, Certificate
-from ..models import CertificateStore
+from ..exceptions import SchemaValidationError, CFDIError
+from ..models import CertificateStore, Certificate
 from ..utils import parser
+from ..catalogs import codigo_postal_uso_horario
 
 __all__ = [
-    'TRANSLATIONS',
-    'CATALOGS',
     'SchemaCollector',
     'cfdi_xmlify',
     'cfdi_schemas',
     'cfdi_objectify',
-    'PDF_INIT_TEMPLATE',
     'MEXICO_TZ',
     'get_timezone',
     'validate_xsd',
     'xslt_transform',
-    'verify_certificate',
-    'moneda_decimales'
+    'verify_certificate'
 ]
 
 current_dir = os.path.dirname(__file__)
 SCHEMA_ROOT = os.path.join(current_dir, "schemas")
-PDF_INIT_TEMPLATE = DefaultPDFEnvironment.get_template("_init.html")
 SAT_Certificate_Store = None
 
-
-def moneda_decimales(moneda):
-    return CATALOGS['{http://www.sat.gob.mx/sitio_internet/cfd/catalogos}c_Moneda'][moneda][1]
-
-
-# America/Chihuahua, America/Mazatlan
 HUSO_HORARIOS = {
-    "Tiempo del Centro en Frontera": "America/Monterrey",
-    "Tiempo del Centro": "America/Mexico_City",
-    "Tiempo del Noroeste en Frontera": "America/Matamoros",
-    "Tiempo del Pacífico Sonora": "America/Hermosillo",
-    "Tiempo del Pacífico en Frontera": "America/Tijuana",
-    "Tiempo del Pacífico": "America/La_Paz",
-    "Tiempo del Sureste": "America/Cancun",
+    'Tiempo del Centro': "America/Mexico_City",
+    'Tiempo del Centro en Frontera': "America/Monterrey",
+    'Tiempo del Noroeste': "America/Matamoros",
+    'Tiempo del Pacífico': "America/La_Paz",
+    'Tiempo del Sureste': "America/Cancun"
 }
 
 
@@ -61,7 +46,7 @@ def _pytz_timezone(tz):
 
 def get_timezone(codigo_postal):
     tz = HUSO_HORARIOS[
-        CATALOGS['{http://www.sat.gob.mx/sitio_internet/cfd/catalogos}c_CodigoPostal'][codigo_postal][4]
+        codigo_postal_uso_horario(codigo_postal)
     ]
 
     return _pytz_timezone(tz)
