@@ -3,7 +3,15 @@ from collections.abc import Sequence, Mapping
 
 from lxml import etree
 
-parser = etree.XMLParser(no_network=True, remove_comments=True, remove_blank_text=True, huge_tree=True, collect_ids=False, remove_pis=True)
+parser = etree.XMLParser(
+    no_network=True,
+    remove_comments=True,
+    remove_blank_text=True,
+    huge_tree=True,
+    collect_ids=False,
+    remove_pis=True,
+    recover=True
+)
 
 
 class ScalarMap(dict):
@@ -12,14 +20,17 @@ class ScalarMap(dict):
 
 def iterate(item):
     if isinstance(item, str | bytes | ScalarMap):
-        return [item]
+        yield item
+        return
     if isinstance(item, Mapping):
-        return item.values()
+        yield from item.values()
+        return
     if isinstance(item, Sequence):
-        return item
+        yield from item
+        return
     if item is None:
-        return []
-    return [item]
+        return
+    yield item
 
 
 class StrEnum(str, enum.Enum):  # Compatible with Python 3.10
@@ -28,3 +39,7 @@ class StrEnum(str, enum.Enum):  # Compatible with Python 3.10
 
     def __format__(self, format_spec):
         return self.value.__format__(format_spec)
+
+    @classmethod
+    def get(cls, key, default=None):
+        return cls._member_map_.get(key, default)
