@@ -1,21 +1,16 @@
-import filecmp
 import glob
-import json
 import os
 from unittest import mock
-
+from uuid import UUID
+from datetime import datetime
 import xlsxwriter
-from lxml.etree import QName
-from satcfdi.printer import Representable
 
-from satcfdi.transform.pdf_environment import PDFEnvironment
-
-from satcfdi import DatePeriod
 from satcfdi.accounting._ansi_colors import *
 from satcfdi.accounting.formatters import SatCFDI
+from satcfdi.create.catalogos import EstadoComprobante
 from satcfdi.accounting.process import filter_invoices_iter, invoices_export, invoices_print, payments_print, \
     complement_invoices_data, payments_export, num2col, filter_payments_iter, payments_retentions_export, filter_retenciones_iter, retenciones_print, payments_groupby_receptor
-from tests.utils import verify_result
+from satcfdi.models import DatePeriod
 
 current_dir = os.path.abspath(os.path.dirname(__file__))
 
@@ -31,9 +26,8 @@ def test_ansi():
 
 
 class myCFDI(SatCFDI):
-    @SatCFDI.estatus.getter
-    def estatus(self) -> str:
-        return '1'
+    def estatus(self) -> EstadoComprobante:
+        return EstadoComprobante.VIGENTE
 
     def consulta_estado(self):
         return {}
@@ -55,6 +49,18 @@ def test_cfdi():
         d = c.ultima_num_parcialidad
         assert d >= 0
 
+    cfdi_pagado = all_invoices[UUID("6d7434a6-e3f2-47ad-9e4c-08849946afa0")]
+
+    assert cfdi_pagado.ultima_num_parcialidad == 1
+    assert cfdi_pagado.saldo_pendiente() == 0
+    assert cfdi_pagado.saldo_pendiente(datetime(2020, 1, 2)) == cfdi_pagado['Total']
+    assert cfdi_pagado.saldo_pendiente(datetime(2020, 1, 3)) == 0
+
+    cfdi_pagado.payments[0].comprobante.estatus = lambda: EstadoComprobante.CANCELADO
+
+    assert cfdi_pagado.ultima_num_parcialidad == 0
+    assert cfdi_pagado.saldo_pendiente() == cfdi_pagado['Total']
+
     with mock.patch('builtins.print') as p:
         ingresos_pendientes = list(filter_invoices_iter(invoices=all_invoices.values(), fecha=dp, rfc_emisor=rfc, invoice_type="I", pending_balance=lambda x: x > 0))
         invoices_print(ingresos_pendientes)
@@ -74,6 +80,7 @@ def test_cfdi():
         pagos_hechos = list(filter_payments_iter(invoices=all_invoices, fecha=dp, rfc_receptor=rfc))
         payments_print(pagos_hechos)
 
+        os.makedirs(os.path.join(current_dir, "test_accounting"), exist_ok=True)
         path = os.path.join(current_dir, "test_accounting", "invoices.xlsx")
 
         workbook = xlsxwriter.Workbook(path)
@@ -98,26 +105,3 @@ def test_retenciones():
 
     retenciones = filter_retenciones_iter(all_invoices, ejerc=year)
     retenciones_print(retenciones)
-
-
-def test_single_html_file():
-    all_invoices = []
-    for f in glob.iglob(os.path.join(current_dir, "invoices", "*.xml")):
-        c = myCFDI.from_file(f)
-        all_invoices.append(c)
-
-    res = Representable.html_str_all(all_invoices)
-    verify_result(res, "multiple_invoices.html")
-
-    Representable.html_write_all(
-        objs=all_invoices,
-        target=os.path.join(current_dir, "test_accounting", "multiple_invoices2.html"),
-    )
-
-    with open(os.path.join(current_dir, "test_accounting", "multiple_invoices2.html"), "r", encoding='utf-8') as f:
-        assert f.read() == res
-
-    # assert filecmp.cmp(
-    #     os.path.join(current_dir, "test_accounting", "multiple_invoices.html"),
-    #     os.path.join(current_dir, "test_accounting", "multiple_invoices2.html")
-    # )
