@@ -2,8 +2,10 @@ import os
 from datetime import datetime
 from decimal import Decimal
 
+from satcfdi import render
 from satcfdi.create.addendas import dvz11
 from satcfdi.create.cfd import cfdi40
+from satcfdi.create.cfd.catalogos import Impuesto, TipoFactor
 from satcfdi.pacs.sat import SAT
 from tests.utils import get_signer, verify_result, XElementPrettyPrinter
 
@@ -25,7 +27,7 @@ def verify_invoice(invoice, path, include_metadata=False):
     verify = verify_result(data=invoice.xml_bytes(pretty_print=True), filename=f"{path}.xml")
     assert verify
 
-    verify = verify_result(data=invoice.html_str(), filename=f"{path}.html")
+    verify = verify_result(data=render.html_str(invoice), filename=f"{path}.html")
     assert verify
 
 
@@ -61,8 +63,23 @@ def test_create_addenda():
                 descripcion='SERVICIOS DE FACTURACION',
                 valor_unitario=Decimal('15390.30'),
                 impuestos=cfdi40.Impuestos(
-                    traslados=cfdi40.Impuesto.parse('002|Tasa|0.160000'),
-                    retenciones=[cfdi40.Impuesto.parse('001|Tasa|0.100000'), cfdi40.Impuesto.parse('002|Tasa|0.106667')],
+                    traslados=cfdi40.Traslado(
+                        impuesto=Impuesto.IVA,
+                        tipo_factor=TipoFactor.TASA,
+                        tasa_o_cuota=Decimal('0.160000'),
+                    ),
+                    retenciones=[
+                        cfdi40.Retencion(
+                            impuesto=Impuesto.ISR,
+                            tipo_factor=TipoFactor.TASA,
+                            tasa_o_cuota=Decimal('0.100000'),
+                        ),
+                        cfdi40.Retencion(
+                            impuesto=Impuesto.IVA,
+                            tipo_factor=TipoFactor.TASA,
+                            tasa_o_cuota=Decimal('0.106667'),
+                        )
+                    ],
                 ),
                 _traslados_incluidos=False
             )
@@ -112,8 +129,23 @@ def test_copy_cfdi():
                 descripcion='SERVICIOS DE FACTURACION',
                 valor_unitario=Decimal('15390.30'),
                 impuestos=cfdi40.Impuestos(
-                    traslados=cfdi40.Impuesto.parse('002|Tasa|0.160000'),
-                    retenciones=[cfdi40.Impuesto.parse('001|Tasa|0.100000'), cfdi40.Impuesto.parse('002|Tasa|0.106667')],
+                    traslados=cfdi40.Traslado(
+                        impuesto=Impuesto.IVA,
+                        tipo_factor=TipoFactor.TASA,
+                        tasa_o_cuota=Decimal('0.160000'),
+                    ),
+                    retenciones=[
+                        cfdi40.Retencion(
+                            impuesto=Impuesto.ISR,
+                            tipo_factor=TipoFactor.TASA,
+                            tasa_o_cuota=Decimal('0.100000'),
+                        ),
+                        cfdi40.Retencion(
+                            impuesto=Impuesto.IVA,
+                            tipo_factor=TipoFactor.TASA,
+                            tasa_o_cuota=Decimal('0.106667'),
+                        )
+                    ],
                 ),
                 _traslados_incluidos=False
             )
@@ -124,4 +156,4 @@ def test_copy_cfdi():
     copy = invoice.copy()
     verify_invoice(copy, f"{xml_file}")
 
-    copy.json_str(pretty_print=True)
+    render.json_str(copy, pretty_print=True)
