@@ -5,8 +5,10 @@ from unittest import mock
 
 import pytest
 
+from satcfdi import render
 from satcfdi.cfdi import CFDI
 from satcfdi.create.cfd import cfdi33, nomina12
+from satcfdi.create.cfd.catalogos import Impuesto, TipoFactor
 from satcfdi.create.cfd.cfdi40 import PagoComprobante
 from satcfdi.pacs.sat import SAT
 from tests.utils import get_signer, verify_result, _uuid, stamp_v11, SAT_Certificate_Store_Pruebas, XElementPrettyPrinter
@@ -17,12 +19,13 @@ current_filename = os.path.splitext(os.path.basename(__file__))[0]
 sat = SAT()
 
 invoices = [
-    ('xiqb891116qe4', "xiqb891116qe4_ingreso_noobjeto", None, [cfdi33.Impuesto.parse('001|Tasa|0.100000')], '13851.27', False),
+    ('xiqb891116qe4', "xiqb891116qe4_ingreso_noobjeto", None, [cfdi33.Traslado(impuesto=Impuesto.ISR, tipo_factor=TipoFactor.TASA, tasa_o_cuota=Decimal('0.100000'))], '13851.27', False),
     # ('xiqb891116qe4', "xiqb891116qe4_ingreso_exento", cfdi33.Traslado.IVA_EXENTO, [cfdi33.Retencion.ISR10], '13851.27', False),
-    ('xiqb891116qe4', "xiqb891116qe4_ingreso_iva16", cfdi33.Impuesto.parse('002|Tasa|0.160000'), [cfdi33.Impuesto.parse('001|Tasa|0.100000'), cfdi33.Impuesto.parse('002|Tasa|0.106667')], '14672.08', False),
+    ('xiqb891116qe4', "xiqb891116qe4_ingreso_iva16", cfdi33.Traslado(impuesto=Impuesto.IVA, tipo_factor=TipoFactor.TASA, tasa_o_cuota=Decimal('0.160000')),
+     [cfdi33.Traslado(impuesto=Impuesto.ISR, tipo_factor=TipoFactor.TASA, tasa_o_cuota=Decimal('0.100000')), cfdi33.Traslado(impuesto=Impuesto.IVA, tipo_factor=TipoFactor.TASA, tasa_o_cuota=Decimal('0.106667'))], '14672.08', False),
     ('h&e951128469', "h&e951128469_ingreso_noobjeto", None, None, '15390.30', False),
     # ('h&e951128469', "h&e951128469_ingreso_exento", cfdi33.Traslado.IVA_EXENTO, None, '15390.30', False),
-    ('h&e951128469', "h&e951128469_ingreso_iva16", cfdi33.Impuesto.parse('002|Tasa|0.160000'), None, '17852.75', False),
+    ('h&e951128469', "h&e951128469_ingreso_iva16", cfdi33.Traslado(impuesto=Impuesto.IVA, tipo_factor=TipoFactor.TASA, tasa_o_cuota=Decimal('0.160000')), None, '17852.75', False),
     # ('h&e951128469', "h&e951128469_ingreso_ieps_exento", cfdi33.Traslado.IEPS_EXENTO, None, '15390.30', False)
 ]
 
@@ -39,7 +42,7 @@ def verify_invoice(invoice, path, include_metadata=False):
     verify = verify_result(data=invoice.xml_bytes(pretty_print=True), filename=f"{path}.xml")
     assert verify
 
-    verify = verify_result(data=invoice.html_str(), filename=f"{path}.html")
+    verify = verify_result(data=render.html_str(invoice), filename=f"{path}.html")
     assert verify
 
 
@@ -87,7 +90,7 @@ def test_create_invoice(rfc, xml_file, traslados, retenciones, total, traslado_i
 
     # Stamping
     with mock.patch('uuid.uuid4', _uuid), \
-            mock.patch(f'{module}.Certificate.rfc_pac', "SAT970701NN3"):
+            mock.patch(f'{module}.models.Certificate.rfc_pac', "SAT970701NN3"):
         stamp_v11(invoice, signer=signer, date=datetime(year=2020, month=1, day=11))
 
     verify_invoice(invoice, f"{xml_file}_stamped")
@@ -98,7 +101,7 @@ def test_create_invoice(rfc, xml_file, traslados, retenciones, total, traslado_i
     # Verify Signature
     with mock.patch(f'{module}.transform.SAT_Certificate_Store', SAT_Certificate_Store_Pruebas), \
             mock.patch(f'{module}.pacs.sat.SAT.recover_certificate', from_no_certificado), \
-            mock.patch(f'{module}.Certificate.rfc_pac', "SAT970701NN3"):
+            mock.patch(f'{module}.models.Certificate.rfc_pac', "SAT970701NN3"):
         ver = sat.validate(invoice)
         assert ver
 
