@@ -5,11 +5,13 @@ from unittest import mock
 
 import pytest
 
+from satcfdi import render
 from satcfdi.cfdi import CFDI
 from satcfdi.create.cfd import cfdi40, nomina12
+from satcfdi.create.cfd.catalogos import Impuesto, TipoFactor
 from satcfdi.create.cfd.cfdi40 import PagoComprobante
 from satcfdi.pacs.sat import SAT
-from tests.utils import get_signer, verify_result, _uuid, get_rfc_pac, stamp_v11, SAT_Certificate_Store_Pruebas, XElementPrettyPrinter
+from tests.utils import get_signer, verify_result, _uuid, stamp_v11, SAT_Certificate_Store_Pruebas, XElementPrettyPrinter
 
 module = 'satcfdi'
 current_dir = os.path.dirname(__file__)
@@ -17,16 +19,21 @@ current_filename = os.path.splitext(os.path.basename(__file__))[0]
 sat = SAT()
 
 invoices = [
-    ('xiqb891116qe4', "xiqb891116qe4_ingreso_noobjeto", None, [cfdi40.Impuesto.parse('001|Tasa|0.100000')], '13851.27', False),
-    ('xiqb891116qe4', "xiqb891116qe4_ingreso_exento", cfdi40.Impuesto.parse('002|Exento'), [cfdi40.Impuesto.parse('001|Tasa|0.100000')], '13851.27', False),
-    ('xiqb891116qe4', "xiqb891116qe4_ingreso_iva16", 'IVA|Tasa|0.160000', ['ISR|Tasa|0.100000', cfdi40.Impuesto.parse('IVA|Tasa|0.106667')], '14672.08', False),
+    ('xiqb891116qe4', "xiqb891116qe4_ingreso_noobjeto", None, [cfdi40.Traslado(impuesto=Impuesto.ISR, tipo_factor=TipoFactor.TASA, tasa_o_cuota=Decimal('0.100000'))], '13851.27', False),
+    ('xiqb891116qe4', "xiqb891116qe4_ingreso_exento", cfdi40.Traslado(impuesto=Impuesto.IVA, tipo_factor=TipoFactor.EXENTO), [cfdi40.Traslado(impuesto=Impuesto.ISR, tipo_factor=TipoFactor.TASA, tasa_o_cuota=Decimal('0.100000'))], '13851.27', False),
+    ('xiqb891116qe4', "xiqb891116qe4_ingreso_iva16", cfdi40.Traslado(impuesto=Impuesto.IVA, tipo_factor=TipoFactor.TASA, tasa_o_cuota=Decimal('0.160000')), [cfdi40.Traslado(impuesto=Impuesto.ISR, tipo_factor=TipoFactor.TASA, tasa_o_cuota=Decimal('0.100000')), cfdi40.Traslado(impuesto=Impuesto.IVA, tipo_factor=TipoFactor.TASA, tasa_o_cuota=Decimal('0.106667'))], '14672.08', False),
     ('h&e951128469', "h&e951128469_ingreso_noobjeto", None, None, '15390.30', False),
-    ('h&e951128469', "h&e951128469_ingreso_exento", cfdi40.Impuesto.parse('002|Exento'), None, '15390.30', False),
-    ('h&e951128469', "h&e951128469_ingreso_iva16", cfdi40.Impuesto.parse('002|Tasa|0.160000'), None, '17852.75', False),
-    ('h&e951128469', "h&e951128469_ingreso_ieps_exento", cfdi40.Impuesto.parse('003|Exento'), None, '15390.30', False)
+    ('h&e951128469', "h&e951128469_ingreso_exento", cfdi40.Traslado(impuesto=Impuesto.IVA, tipo_factor=TipoFactor.EXENTO), None, '15390.30', False),
+    ('h&e951128469', "h&e951128469_ingreso_iva16", cfdi40.Traslado(impuesto=Impuesto.IVA, tipo_factor=TipoFactor.TASA, tasa_o_cuota=Decimal('0.160000')), None, '17852.75', False),
+    ('h&e951128469', "h&e951128469_ingreso_ieps_exento", cfdi40.Traslado(impuesto=Impuesto.IEPS, tipo_factor=TipoFactor.EXENTO), None, '15390.30', False)
 ]
 
 
+def test_catalog():
+    v = Impuesto.get("IVA", "IVA")
+    assert v == "002"
+
+
 def verify_invoice(invoice, path, include_metadata=False):
     if include_metadata:
         verify = verify_result(data=invoice.metadata, filename=f"{path}.txt")
@@ -39,7 +46,7 @@ def verify_invoice(invoice, path, include_metadata=False):
     verify = verify_result(data=invoice.xml_bytes(pretty_print=True), filename=f"{path}.xml")
     assert verify
 
-    verify = verify_result(data=invoice.html_str(), filename=f"{path}.html")
+    verify = verify_result(data=render.html_str(invoice), filename=f"{path}.html")
     assert verify
 
 
@@ -78,8 +85,12 @@ def test_traslados_incluidos():
                     descripcion='SERVICIOS DE FACTURACION',
                     valor_unitario=valor,
                     impuestos=cfdi40.Impuestos(
-                        traslados=cfdi40.Impuesto.parse('002|Tasa|0.160000'),
-                        retenciones=None,
+                        traslados=cfdi40.Traslado(
+                            impuesto=Impuesto.IVA,
+                            tipo_factor=TipoFactor.TASA,
+                            tasa_o_cuota=Decimal('0.160000'),
+                        ),
+                        retenciones=None
                     ),
                     _traslados_incluidos=True
                 )
@@ -89,62 +100,7 @@ def test_traslados_incluidos():
 
         assert invoice["Total"] == valor * Decimal('23.00')
 
-
-@pytest.mark.parametrize('rfc, xml_file, traslados, retenciones, total, traslado_incluido', invoices)
-@pytest.mark.skip(reason="skiping render for performance reasons")
-def test_create_invoice_render(rfc, xml_file, traslados, retenciones, total, traslado_incluido):
-    xml_file = "_render" + xml_file
-    signer = get_signer(rfc)
-    emisor = cfdi40.Emisor(
-        rfc=signer.rfc,
-        nombre=signer.legal_name,
-        regimen_fiscal="601"
-    )
-
-    invoice = cfdi40.Comprobante(
-        emisor=emisor,
-        lugar_expedicion="56820",
-        fecha=datetime.fromisoformat("2020-01-01T22:40:38"),
-        receptor=cfdi40.Receptor(
-            rfc='KIJ0906199R1',
-            nombre='KIJ, S.A DE C.V.',
-            uso_cfdi='G03',
-            domicilio_fiscal_receptor="59820",
-            regimen_fiscal_receptor="601"
-        ),
-        metodo_pago='PPD',
-        serie="A",
-        folio="123456",
-        conceptos=[
-            cfdi40.Concepto(
-                cuenta_predial='1234567890',
-                clave_prod_serv='10101702',
-                cantidad=Decimal('1.00'),
-                clave_unidad='E48',
-                descripcion='SERVICIOS DE FACTURACION',
-                valor_unitario=Decimal('15390.30'),
-                impuestos=cfdi40.Impuestos(
-                    traslados=traslados,
-                    retenciones=retenciones,
-                ),
-                _traslados_incluidos=traslado_incluido,
-            )
-        ]
-    )
-    invoice.sign(signer)
-
-    assert invoice["Total"] == Decimal(total)
-
-    # Stamping
-    with mock.patch('uuid.uuid4', _uuid), \
-            mock.patch(f'{module}.Certificate.rfc_pac', get_rfc_pac):
-        stamp_v11(invoice, signer=signer, date=datetime(year=2020, month=1, day=11))
-
-    path = f"{xml_file}_stamped"
-
-    os.makedirs(os.path.join(current_dir, 'renders'), exist_ok=True)
-    invoice.html_write(target=os.path.join(current_dir, 'renders', f"{path}.html"))
-    invoice.pdf_write(target=os.path.join(current_dir, 'renders', f"{path}.pdf"))
+        render.pdf_write(invoice, target=os.path.join(current_dir, current_filename, f"test_traslados_incluidos_render.pdf"))
 
 
 @pytest.mark.parametrize('rfc, xml_file, traslados, retenciones, total, traslado_incluido', invoices)
@@ -194,7 +150,7 @@ def test_create_invoice(rfc, xml_file, traslados, retenciones, total, traslado_i
 
     # Stamping
     with mock.patch('uuid.uuid4', _uuid), \
-            mock.patch(f'{module}.Certificate.rfc_pac', "SAT970701NN3"):
+            mock.patch(f'{module}.models.Certificate.rfc_pac', "SAT970701NN3"):
         stamp_v11(invoice, signer=signer, date=datetime(year=2020, month=1, day=11))
 
     # with mock.patch(f'{module}.cfdi.CFDI.estatus', '1'), mock.patch(f'{module}.cfdi.CFDI.fecha_cancelacion', None):
@@ -206,7 +162,7 @@ def test_create_invoice(rfc, xml_file, traslados, retenciones, total, traslado_i
     # Verify Signature
     with mock.patch(f'{module}.transform.SAT_Certificate_Store', SAT_Certificate_Store_Pruebas), \
             mock.patch(f'{module}.pacs.sat.SAT.recover_certificate', from_no_certificado), \
-            mock.patch(f'{module}.Certificate.rfc_pac', "SAT970701NN3"):
+            mock.patch(f'{module}.models.Certificate.rfc_pac', "SAT970701NN3"):
         ver = sat.validate(invoice)
         assert ver
 
