@@ -5,6 +5,7 @@ from io import BytesIO
 from unittest import mock
 from zipfile import ZipInfo
 
+from satcfdi import render
 from satcfdi.diot.code import Periodo, TipoOperacion, TipoTercero, Pais
 from satcfdi.diot import DatosIdentificacion, DatosComplementaria, ProveedorTercero, DIOT
 from tests.utils import get_signer, verify_result
@@ -47,7 +48,7 @@ def test_create_filename():
             periodo=Periodo.OCTUBRE,
             proveedores=[]
         )
-        assert diot._tmp_filename() == 'XIQB891116QE40DOTAAM1MCMB811401'
+        assert diot.filename() == 'XIQB891116QE40DOTAAM1MCMB811401'
 
     with mock.patch(f'{module}.diot.datetime') as m:
         p = ProveedorTercero(
@@ -63,7 +64,7 @@ def test_create_filename():
             periodo=Periodo.OCTUBRE,
             proveedores=[p for _ in range(40001)]
         )
-        assert diot._tmp_filename() == 'XIQB891116QE40DOTAAM1MCMB813202'
+        assert diot.filename() == 'XIQB891116QE40DOTAAM1MCMB813202'
 
     rfc = "OÑO120726RX3"
     with mock.patch(f'{module}.diot.datetime') as m:
@@ -76,7 +77,7 @@ def test_create_filename():
             periodo=Periodo.OCTUBRE,
             proveedores=[]
         )
-        assert diot._tmp_filename() == '_OÑO120726RX30DOTAAM1MCMB817181'
+        assert diot.filename() == '_OÑO120726RX30DOTAAM1MCMB817181'
 
 
 xiqb891116qe4_issuer = DatosIdentificacion(
@@ -104,7 +105,7 @@ def test_create_declaracion_diot():
     # Verify FILENAME
     with mock.patch(f'{module}.diot.datetime') as m:
         m.now = mock.Mock(return_value=datetime(2022, 11, 8, 11, 40))
-        tmp_filename = diot._tmp_filename()
+        tmp_filename = diot.filename()
         assert tmp_filename == text_file
 
     # Verify ZIP
@@ -130,7 +131,7 @@ def test_create_declaracion_diot():
             if dig == 24:
                 return b'\x9e@@hL\xcd\xf2\x9eR\xe6JC\xc8\xba\x8a\xf1C\xec\rE*\x16 4'
 
-        with mock.patch(f'{module}.Certificate.encrypt', encrypt), mock.patch('os.urandom', rand):
+        with mock.patch(f'{module}.models.Certificate.encrypt', encrypt), mock.patch('os.urandom', rand):
             dec_data = diot._encrypted_bytes(tmp_filename)
             assert dec_data == open(os.path.join(current_dir, 'diot', f'{text_file}.dec'), 'rb').read()
 
@@ -301,7 +302,7 @@ def test_create_declaracion_diot_moral_full():
 
 
 def verify_invoice(invoice, path):
-    verify = verify_result(data=invoice.html_str(), filename=f"{path}.html")
+    verify = verify_result(data=render.html_str(invoice), filename=f"{path}.html")
     assert verify
 
 
