@@ -4,6 +4,7 @@ from decimal import Decimal
 from unittest import mock
 
 from satcfdi.create.cfd import cfdi40
+from satcfdi.create.cfd.catalogos import Impuesto, TipoFactor
 from satcfdi.pacs import Environment
 from satcfdi.pacs.comerciodigital import ComercioDigital
 from utils import get_signer, verify_result
@@ -46,8 +47,23 @@ def test_comercio_digital_test():
             descripcion='SERVICIOS DE RENTA',
             valor_unitario=Decimal("1.00"),
             impuestos=cfdi40.Impuestos(
-                traslados=cfdi40.Impuesto.parse('002|Tasa|0.160000'),
-                retenciones=[cfdi40.Impuesto.parse('001|Tasa|0.100000'), cfdi40.Impuesto.parse('002|Tasa|0.106667')],
+                traslados=cfdi40.Traslado(
+                    impuesto=Impuesto.IVA,
+                    tipo_factor=TipoFactor.TASA,
+                    tasa_o_cuota=Decimal('0.160000'),
+                ),
+                retenciones=[
+                    cfdi40.Retencion(
+                        impuesto=Impuesto.ISR,
+                        tipo_factor=TipoFactor.TASA,
+                        tasa_o_cuota=Decimal('0.100000'),
+                    ),
+                    cfdi40.Retencion(
+                        impuesto=Impuesto.IVA,
+                        tipo_factor=TipoFactor.TASA,
+                        tasa_o_cuota=Decimal('0.106667'),
+                    )
+                ],
             ),
             _traslados_incluidos=True
         )
